sqlobject.tests.test_sqlmeta_idName module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sqlmeta_idName module

class `sqlobject.tests.test_sqlmeta_idName.` `SOTestSqlmeta1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_sqlmeta1
  `q` = so_test_sqlmeta1
  class `sqlmeta`(instance)

    Bases: `sqlobject.tests.test_sqlmeta_idName.myid_sqlmeta`

    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlmeta_idName.SOTestSqlmeta1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_sqlmeta1'

class `sqlobject.tests.test_sqlmeta_idName.` `SOTestSqlmeta2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = SOTestSqlmeta2
  `q` = SOTestSqlmeta2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'SOTestSqlmeta2ID'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlmeta_idName.SOTestSqlmeta2`

    `style` = <sqlobject.styles.MixedCaseStyle object>
    `table` = 'SOTestSqlmeta2'

class `sqlobject.tests.test_sqlmeta_idName.` `SOTestSqlmeta3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = SOTestSqlmeta3
  `q` = SOTestSqlmeta3
  class `sqlmeta`(instance)

    Bases: `sqlobject.tests.test_sqlmeta_idName.myid_sqlmeta`

    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlmeta_idName.SOTestSqlmeta3`

    `style` = <sqlobject.styles.MixedCaseStyle object>
    `table` = 'SOTestSqlmeta3'

class `sqlobject.tests.test_sqlmeta_idName.` `SOTestSqlmeta4`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = SOTestSqlmeta4
  `q` = SOTestSqlmeta4
  class `sqlmeta`(instance)

    Bases: `sqlobject.tests.test_sqlmeta_idName.myid_sqlmeta`

    `childName` = None
    `idName` = 'SOTestSqlmeta4ID'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlmeta_idName.SOTestSqlmeta4`

    `style` = <sqlobject.styles.MixedCaseStyle object>
    `table` = 'SOTestSqlmeta4'

class `sqlobject.tests.test_sqlmeta_idName.` `SOTestSqlmeta5`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = SOTestSqlmeta5
  `q` = SOTestSqlmeta5
  class `sqlmeta`(instance)

    Bases: `sqlobject.tests.test_sqlmeta_idName.longid_sqlmeta`

    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlmeta_idName.SOTestSqlmeta5`

    `table` = 'SOTestSqlmeta5'

class `sqlobject.tests.test_sqlmeta_idName.` `SOTestSqlmeta6`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = SOTestSqlmeta6
  `q` = SOTestSqlmeta6
  class `sqlmeta`(instance)

    Bases: `sqlobject.tests.test_sqlmeta_idName.longid_sqlmeta`

    `childName` = None
    `idName` = 'SOTestSqlmeta6ID'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlmeta_idName.SOTestSqlmeta6`

    `table` = 'SOTestSqlmeta6'

class `sqlobject.tests.test_sqlmeta_idName.` `longid_sqlmeta`(instance)

  Bases: `sqlobject.main.sqlmeta`

  `childName` = None
  `idName` = 'my_id'
  `style` = <sqlobject.styles.MixedCaseStyle object>
  `table` = None

class `sqlobject.tests.test_sqlmeta_idName.` `myid_sqlmeta`(instance)

  Bases: `sqlobject.main.sqlmeta`

  `childName` = None
  `idName` = 'my_id'
  `table` = None

`sqlobject.tests.test_sqlmeta_idName.` `test_sqlmeta_inherited_idName`()